local ShowMotifs = ShowMotifs

-- here we will keep our settings and will make a menu to change them
ShowMotifs.ShowMotifsSettings = ZO_Object:Subclass()

local LAM = LibStub("LibAddonMenu-2.0")
local settings = nil

-- list of available themes
local TEXTURE_OPTIONS = { "Default", "Alphabetic", "Materials" }

-- function to initialize our settings object
function ShowMotifs.ShowMotifsSettings:New()
	local obj = ZO_Object.New(self)
	obj:Initialize()
	return obj
end

-- default settings if none found
function ShowMotifs.ShowMotifsSettings:Initialize()
	local defaults = {
		smToggle = true,
		showTooltips = false,
		MotifTextureSize = 32,
		ArmorTextureSize = 32,
		textureName = "Default",
		position = -72,
		IsMotifIcon = true,
		IsArmorIcon = true,
		IsArmorLetter = false,
		ColorIcon = true,
		BorderIcon = true,
	}

	settings = ZO_SavedVars:NewAccountWide("ShowMotifs_Settings", 2, nil, defaults)

    self:CreateOptionsMenu()
end

-- function to check if module is activated
function ShowMotifs.ShowMotifsSettings:IsActivated()
	return settings.smToggle

end

-- function to check if tooltips are enabled
function ShowMotifs.ShowMotifsSettings:ShowTooltips()
	return settings.showTooltips
end

-- function to check if racial motifs icons are enabled
function ShowMotifs.ShowMotifsSettings:IsMotifIconEnabled()
	return settings.IsMotifIcon
end

-- function to check if armor type icons are enabled
function ShowMotifs.ShowMotifsSettings:IsArmorIconEnabled()
	return settings.IsArmorIcon
end

-- function checks if we have necessary dates for racial motif <<MotifID>>
function ShowMotifs.ShowMotifsSettings:GetMotif(MotifID)
	if ( ShowMotifs.STYLES_TEXTURES[settings.textureName][MotifID] and ShowMotifs.STYLES_TEXTURES[settings.textureName][MotifID].texture ) then
		return true
	else
		return false
	end
end

-- function returns path to icon texture for racial motif <<MotifID>>
function ShowMotifs.ShowMotifsSettings:GetMotifTexture(MotifID)
	return ShowMotifs.STYLES_TEXTURES[settings.textureName][MotifID].texture
end

-- function returns path to icon texture for armor type <<TextureTypeID>>
function ShowMotifs.ShowMotifsSettings:GetArmorTexture(TextureTypeID)
	if ( settings.IsArmorLetter ) then
		return ShowMotifs.ARMOR_TEXTURES[settings.textureName][TextureTypeID].letter
	end
	
	return ShowMotifs.ARMOR_TEXTURES[settings.textureName][TextureTypeID].texture
end

-- function returns name of armor type based on in-game strings
function ShowMotifs.ShowMotifsSettings:GetArmorName(TextureTypeID)
	if ( self:GetLang() == "fr" ) then
		return GetString(SI_ITEM_FORMAT_STR_ARMOR) .. " " .. GetString(_G['SI_ARMORTYPE' .. TextureTypeID])
	end

	return GetString(_G['SI_ARMORTYPE' .. TextureTypeID]) .. " " .. GetString(SI_ITEM_FORMAT_STR_ARMOR)
end

-- function returns name of racial motif based on in-game strings
function ShowMotifs.ShowMotifsSettings:GetMotifName(TextureTypeID)
	return GetString(_G['SI_ITEMSTYLE' .. TextureTypeID])
end

function ShowMotifs.ShowMotifsSettings:GetMotifTextureSize()
	return settings.MotifTextureSize
end

-- function returns icon size for armor type icon
function ShowMotifs.ShowMotifsSettings:GetArmorTextureSize()
	return settings.ArmorTextureSize
end

-- function returns icon size for racial motif icon
function ShowMotifs.ShowMotifsSettings:GetIconPosition()
	return settings.position
end

-- function to check if we should use quality colors for icons
function ShowMotifs.ShowMotifsSettings:GetIconColor()
	return settings.ColorIcon
end

-- function to check if we should use rarity border for icons
function ShowMotifs.ShowMotifsSettings:GetBorderIcon()
	return settings.BorderIcon
end

-- function to check client locale
function ShowMotifs.ShowMotifsSettings:GetLang()
	local lang = GetCVar("language.2")
	if ( lang == "de" or lang == "en" or lang == "fr" ) then
		return lang
	end
	return "en"
end


-- function to create settings menu. It uses LibAddonMenu v2
function ShowMotifs.ShowMotifsSettings:CreateOptionsMenu()
--	load phrases based on client locale
	local phrases = ShowMotifs.LOCALES[self:GetLang()].phrases

--	initialize main panel for our settings
	local lampanel = {
		type = "panel",
		name = "Show Motifs",
		author = "mra4nii",
		version = "0.9.9",
		slashCommand = "/showmotifs",
		registerForRefresh = true,
		registerForDefaults = true,
	}
	
--	show an icon, so we can see how theme looks
	local icon = WINDOW_MANAGER:CreateControl("ShowMotifsSettingsPanel_Icon", ZO_OptionsWindowSettingsScrollChild, CT_TEXTURE)
	icon:SetColor(255, 255, 255, 1)
	icon:SetHandler("OnShow", function()
--			icon:SetTexture(ShowMotifs.STYLES_TEXTURES[settings.textureName][ITEMSTYLE_RACIAL_HIGH_ELF].texture)
--			icon:SetDimensions(settings.MotifTextureSize, settings.MotifTextureSize)
	end)

--	populate our settings menu
	local lamoptions = {
		[1] = {
			type = "header",
			name = phrases.GENERAL,
		},
--	dropdown menu to select themes		
		[2] = {
			type = "dropdown",
			name = phrases.ICON_THEME,
			tooltip = phrases.ICON_THEME_TOOLTIP,
			choices = TEXTURE_OPTIONS,
			getFunc = function() return settings.textureName end,
			setFunc = function(value)
						settings.textureName = value
						icon:SetTexture(ShowMotifs.STYLES_TEXTURES[settings.textureName][ITEMSTYLE_RACIAL_HIGH_ELF].texture)
						if ( settings.textureName == "Materials" ) then settings.ColorIcon = false end
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
					end,
			reference = "ShowMotifsSettingsPanel_Icon_Dropdown",
			default = TEXTURE_OPTIONS[1],
		},
--	racial motif size
		[3] = {
			type = "slider",
			name = phrases.ICON_SIZE,
			tooltip = phrases.ICON_SIZE_TOOLTIP,
			min = 16,
			max = 64,
			step = 4,
			getFunc = function() return settings.MotifTextureSize end,
			setFunc = function( value )
				settings.MotifTextureSize = value
				icon:SetDimensions(settings.MotifTextureSize, settings.MotifTextureSize)
				ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = 32,
		},
--	armor type size
		[4] = {
			type = "slider",
			name = phrases.ARMOR_ICON_SIZE,
			tooltip = phrases.ARMOR_ICON_SIZE_TOOLTIP,
			min = 16,
			max = 64,
			step = 4,
			getFunc = function() return settings.ArmorTextureSize end,
			setFunc = function( value )
				settings.ArmorTextureSize = value
				ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = 32
		},
-- icons position
		[5] = {
			type = "slider",
			name = phrases.ICON_POSITION,
			tooltip = phrases.ICON_POSITION_TOOLTIP,
			min = -150,
			max = 150,
			step = 1,
			getFunc = function() return settings.position end,
			setFunc = function( value )
				settings.position = value
				ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = 0,
		},
--	show racial motifs icon
		[6] = {
			type = "checkbox",
			name = phrases.RACIAL,
			tooltip = phrases.RACIAL_TOOLTIP,
			getFunc = function() return settings.IsMotifIcon end,
			setFunc = function(value)
						settings.IsMotifIcon = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = true,
		},
--	show armor type icon
		[7] = {
			type = "checkbox",
			name = phrases.ARMOR,
			tooltip = phrases.ARMOR_TOOLTIP,
			getFunc = function() return settings.IsArmorIcon end,
			setFunc = function(value)
						settings.IsArmorIcon = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = true,
		},
--	show letters
		[8] = {
			type = "checkbox",
			name = phrases.LETTER,
			tooltip = phrases.LETTER_TOOLTIP,
			getFunc = function() return settings.IsArmorLetter end,
			setFunc = function(value)
						settings.IsArmorLetter = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = false,
		},
--	use quality colors
		[9] = {
			type = "checkbox",
			name = phrases.COLOR,
			tooltip = phrases.COLOR_TOOLTIP,
			getFunc = function() return settings.ColorIcon end,
			setFunc = function(value)
						settings.ColorIcon = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = true,
		},
--  show border
		[10] = {
			type = "checkbox",
			name = phrases.BORDER,
			tooltip = phrases.BORDER_TOOLTIP,
			getFunc = function() return settings.BorderIcon end,
			setFunc = function(value)
						settings.BorderIcon = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = true,
		},
--	show tooltips
		[11] = {
			type = "checkbox",
			name = phrases.TOOLTIP,
			tooltip = phrases.TOOLTIP_TOOLTIP,
			getFunc = function() return settings.showTooltips end,
			setFunc = function(value)
						settings.showTooltips = value
						ZO_ScrollList_RefreshVisible(ZO_PlayerInventoryBackpack)
			end,
			default = false,
		},
	}
	
--	register our settings menu and its options
	LAM:RegisterAddonPanel("ShowMotifsSettingsPanel", lampanel)
	LAM:RegisterOptionControls("ShowMotifsSettingsPanel", lamoptions)

--	anchor our theme example icon
	CALLBACK_MANAGER:RegisterCallback("LAM-PanelControlsCreated",
		function()
			icon:SetParent(ShowMotifsSettingsPanel_Icon_Dropdown)
			icon:SetTexture(ShowMotifs.STYLES_TEXTURES[settings.textureName][ITEMSTYLE_RACIAL_HIGH_ELF].texture)
			icon:SetDimensions(settings.MotifTextureSize, settings.MotifTextureSize)
			icon:SetAnchor(CENTER, ShowMotifsSettingsPanel_Icon_Dropdown, CENTER, 18, 0)
		end)	

end

